@@ -8,7 +8,7 @@ use POSIX ();
 use Sys::Info::Constants qw( LIN_REAL_NAME_FIELD );
 use Sys::Info::Driver::OSX;
 
-our $VERSION = '0.73';
+our $VERSION = '0.78';
 
 my %OSVERSION;
 
@@ -52,6 +52,7 @@ sub meta {
     # XXX
     my %swap;
     @swap{ qw/ path size used / } = qw( TODO 0 0);
+    $swap{path} = undef;
 
     my %info;
 
@@ -224,8 +225,8 @@ Sys::Info::Driver::OSX::OS - OSX backend
 
 =head1 DESCRIPTION
 
-This document describes version C<0.73> of C<Sys::Info::Driver::OSX::OS>
-released on C<11 January 2011>.
+This document describes version C<0.78> of C<Sys::Info::Driver::OSX::OS>
+released on C<17 April 2011>.
 
 -
 
@@ -280,7 +281,7 @@ Copyright 2010 - 2011 Burak Gursoy. All rights reserved.
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.10.0 or, 
+it under the same terms as Perl itself, either Perl version 5.12.3 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
